illuminaRead-class: Illumina read
Description
Class representation of the features of an Illumina sequencing read.
Slots
number:- the index of this read in sequencing
cycles:- number of cycles in this read
index:- logical representing whether or not this read is an index read